=======
IOOS QC
=======

.. image:: https://anaconda.org/conda-forge/ioos_qc/badges/version.svg
   :target: https://anaconda.org/conda-forge/ioos_qc
   :alt: conda_forge_package

.. image:: https://travis-ci.org/ioos/ioos_qc.svg?branch=master
   :target: https://travis-ci.org/ioos/ioos_qc
   :alt: build_status

Collection of utilities, scripts and tests to assist in automated
quality assurance and quality control for oceanographic datasets and
observing systems.

`Code <https://github.com/ioos/ioos_qc>`_  |  `Issues <https://github.com/ioos/ioos_qc/issues>`_  |  `Documentation <https://ioos.github.io/ioos_qc/>`_

